\name{Commander}
\alias{Commander}

\title{R Commander}
\description{
  Start the R Commander GUI (graphical user interface)
}
\usage{
Commander()
}

\details{

\bold{Getting Started}

The default R Commander interface consists of (from top to bottom) a menu bar, a toolbar,
a log/script window, and an output window.

Commands to read, write, transform, and analyze data are entered using the menus in the
menu bar at the top of the \emph{Commander} window. Most menu items lead to dialog boxes
requesting further specification. I suggest that you explore the menus to see
what is available.

Below the menu bar is a toolbar with (from left to right) an information field
displaying the name of the active data set; buttons for editing and displaying the active
data set; an information field showing the active statistical model;
and a \emph{Submit} button for re-executing commands in the log/script window.
The information fields for the active data set and active model are actually 
buttons that can be used to select the active data set and model from among, respectively,
data frames or linear and generalized linear model objects in memory.

Almost all commands require an active data set. When the Commander starts, there is no active
data set, as indicated in the data set information field. A data set becomes the active data set
when it is read into memory from an R package or imported from a text file, SPSS data set, or
Minitab data set. In addition, the active data set can be selected from among R data frames
resident in memory. You can therefore switch among data sets during a session.

By default, commands are logged to the log/script window (the
initially empty text window immediately below the toolbar); 
commands and output appear in the output window (the initially empty text window below the
log/script window); and the active data set is attached to the search path. To alter these and
other defaults, see the information below on configuration.
 
Some \code{Rcmdr} dialogs (those in the \emph{Statistics -> Fit models} menu) 
produce linear or generalized 
linear models. When a model is fit, it becomes the active model, as indicated in the information
field in the R Commander toolbar.
Items in the \emph{Models} menu apply to the active model. Initially, there is no active model. 
If there are several models in memory, you can select the active model from among them.

If command logging in turned on, R commands that are generated from the menus and dialog boxes are
entered into the log/script window in the Commander. You can edit these commands in the normal
manner and can also type new commands into the log/script window. Individual commands
can be continued over more than one line, but each line after the first must be indented with
one or more spaces or tabs. The contents of the log/script
window can be saved during or at the end of the session, and a saved script can be loaded into the
log/script window. The contents of the output window can also be edited or saved to a text file.

To re-execute a command or set of commands, select the lines to be executed using
the mouse and press the \emph{Submit} button at the right of the toolbar
(or \emph{Control-R}, for "run"). If no text is selected, the \emph{Submit} button (or \emph{Control-R}) 
submits the line containing the text-insertion cursor. Note that an error will be generated if the submitted
command or commands are incomplete.

Pressing \emph{Control-F} brings up a find-text dialog box (which can also be accessed via 
\emph{Edit -> Find}) to search for text in the log/script window or the output window. Edit functions such as
search are performed in the log/script window unless you first click in the output window to make it the active
window.

Right-clicking the mouse (clicking button 3 on a three-button mouse) in the log/script or output window brings up
a "context" menu with the \emph{Edit}-menu items, plus (in the log/script window) a \emph{Submit} item.

When you
execute commands from the \emph{Commander} window, you must ensure that the sequence of commands
is logical. For example, it makes no sense to fit a statistical model to a data set that has
not been read into memory. 

Exit from the Commander via the \emph{File -> Exit} menu or by closing the \emph{Commander} window.

\bold{Customization and Configuration}

Configuration files reside in the \code{etc} subdirectory of the package.

The \code{Rcmdr} menus can be customized by editing the file \code{Rcmdr-menus.txt}.

Some functions (e.g., \code{hist}) that do not normally create visible printed output when executed
from the \emph{R Console} command prompt will do so --- unless prevented --- when executed from the 
\emph{Commander} log window. Such output
can be suppressed by listing the names of these functions in the \code{log-exceptions.txt} file.

You can add R code to the package, e.g., for creating additional dialogs, by placing files with
file type \code{.R} in the \code{etc} directory, also editing \code{Rcmdr-menus.txt} to provide
additional menus, sub-menus, or menu-items. A demo addition is provided in the file 
\code{BoxCox.demo}. To activate the demo, rename this file to \code{BoxCox.R},
and uncomment the corresponding menu line in \code{Rcmdr-menus.txt}. Alternatively, you can edit 
the source package and recompile it.

The following functions are provided to assist in writing dialogs: \code{activeDataSet}, 
\code{activeModel}, \code{doItAndPrint}, \code{justDoIt}, \code{listDataSets}, 
\code{listGeneralizedLinearModels}, \code{listLinearModels}, \code{logger}. The following global
variables contain information about variables in the active data set: \code{.factors},
\code{.numeric}, \code{.twoLevelFactors}, \code{.variables}. See \code{help("\link{Rcmdr.Utilities}")}
and the manual supplied in the \code{etc} directory of the \code{Rcmdr} package for more information.

In addition, several features are controlled by run-time options, set via the \code{options("Rcmdr")}
command. These options should be set before the package is loaded. If the options are unset, which is
the usual situation, defaults are used. Specify options as a list of \emph{name=value} pairs. You can
set none, one, several, or all options. The available options are as follows:

\describe{
    \item{\code{attach.data.set}}{if \code{TRUE} (the default), the active data set is attached to the
    search path.}
    
    \item{\code{log.commands}}{If \code{TRUE} (the default), commands are echoed to the log/script window;
    if \code{FALSE}, the log/script window is not displayed.}
    
    \item{\code{log.text.color}}{Color for text in the log/script window; the default is \code{"black"}.}
    
    \item{\code{log.font.size}}{The font size, in points, to be used in the log/script window,
    in the output window,
    in recode dialogs, and in compute expressions --- that is, where a monospaced font is used. 
    The default is 10.}
    
    \item{\code{log.width}}{The width of the log/script and output windows, in characters. The default is 80.}
    
    \item{\code{log.height}}{The height of the log/script window, in lines. The default is 10. Setting \code{log.height}
    to 0 has the same effect as setting \code{log.commands} to \code{FALSE}.}
    
    \item{\code{console.output}}{If \code{TRUE}, output is directed to the \emph{R Console}, and the 
    \emph{R Commander} output window is not displayed. The default is \code{FALSE}.}
    
    \item{\code{output.height}}{The height of the output window, in lines. The default is twice the height
    of the log/script window, or 20 if the log/script window is suppressed. Setting \code{output.height}
    to 0 has the same effect as setting \code{console.output} to \code{TRUE}.}
    
    \item{\code{command.text.color}}{Color for commands in the output window; the default is \code{"red"}.}
    
    \item{\code{output.text.color}}{Color for output in the output window; the default is \code{"blue"}.}
    
    \item{\code{placement}}{Placement of the \emph{R Commander} window, in pixels; the default is
    \code{"-40+40"}, which puts the window near the upper-right corner of the screen.}
    
    \item{\code{contrasts}}{Serves the same function as the general \code{contrasts} option; the default is 
    \code{c("contr.Treatment", "contr.poly")}. When the Commander exits, the \code{contrasts}
    option is returned to its pre-existing value. Note that \code{contr.Treatment} is from the \code{car} package.}
    
    \item{\code{grab.focus}}{Set to \code{TRUE} (the default) for the current Tk window to 
    "grab" the focus --- that is, to prevent the focus from being changed to another Tk window.
    On some systems, grabbing the focus in this manner apparently causes the \emph{OK}, \emph{Cancel}, and
    \emph{Help} buttons to be disabled after the user types in a text field. If you experience this
    problem, set the \code{grab.focus} option to \code{FALSE}.}
    
    \item{\code{double.click}}{Set to \code{TRUE} if you want a double-click of the left mouse
    button to press the default button in all dialogs. The default is \code{FALSE}.}
    
    \item{\code{multiple.select.mode}}{Affects the way multiple variables are selected in variable-list boxes.
    If set to \code{"extended"} (the default), left-clicking on a variable selects it and deselects any other
    variables that are selected; Control-left-click toggles
    the selection (and may be used to select additional variables); Shift-left-click extends the selection.
    This is the standard Windows convention. If set
    to \code{"multiple"}, left-clicking toggles the selection of a variable and may be used to select more than one
    variable. This is the behaviour in the Rcmdr prior to version 1.9-10.}
    
    \item{\code{sort.names}}{Set to \code{TRUE} (the default) if you want variable names to be sorted
    alphabetically in variable lists.}
    
    \item{\code{show.edit.button}}{Set to \code{TRUE} (the default) if you want an \emph{Edit} button in the Commander
    window, permitting you to edit the active data set. Windows users may wish to set this option to \code{FALSE}
    to suppress the \emph{Edit} button because changing variable names in the data editor can cause R to crash.}
    
    \item{\code{scale.factor}}{A scaling factor to be applied to all Tk elements, such as fonts. This works well
    only in Windows. The default is \code{NULL}.}
    
    \item{\code{default.font.size}}{The size, in points, of the default font. The default is 10. Unless otherwise 
    specified (see the next item), the default font is \code{"*helvetica-medium-r-normal-*-xx*"}, where \code{xx}
    is the default font size. This option is only for non-Windows systems.}
    
    \item{\code{default.font}}{The default font, as an X11 font specification, given in a character string. 
    If specified, this value takes precedence
    over the default font size (above). This option is only for non-Windows systems.}
    
    \item{\code{tkwait}}{This option addresses a problem that, to my knowledge, is rare, 
    and may occur on some non-Windows systems. If the Commander causes R to hang, 
    then set the \code{tkwait} option to
    \code{TRUE}; otherwise set the option to \code{FALSE} or ignore it. 
    An undesirable side effect of setting
    the \code{tkwait} option to \code{TRUE} is that the R session command prompt is suppressed until the Commander exits.
    One can still enter commands via the log/script window, however. In particular, there is no reason to use this option
    under Windows, and it should not be used with the Windows R GUI with buffered output.}
    }
    
Many options can also be set via the \emph{File -> Options} menu, which will restart the Commander after options are set.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\examples{
    options(Rcmdr=list(log.font.size=12, contrasts=c("contr.Sum", "contr.poly")))
    }
}

\keyword{misc}

\eof
\name{Compute}
\alias{Compute}

\title{Rcmdr Compute Dialog}
\description{
  The compute dialog is used to compute new variables.
}

\details{
The name of the new variable must be
a valid R object name (consisting only of upper and lower-case letters, numerals, and
periods, and not starting with a numeral).

Enter an R expression in the box at the right. The expression is evaluated using the active data set. 

Note that if this expression is later
re-executed from the log window, it will be evaluated in the global environment; when the
expression is re-evaluated, the active data set must be attached to the search path 
and the variables in the expression must not be masked by other variables of the same name.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{Arithmetic}}}

\keyword{manip}

\eof
\name{Hist}
\alias{Hist}
\title{Plot a Histogram}

\description{
  This function is a wrapper for the \code{\link[base]{hist}} function in
  the \code{base} package, permitting percentage scaling of the
  vertical axis in addition to frequency and density scaling.
}

\usage{
Hist(x, scale = c("frequency", "percent", "density"), ...)
}

\arguments{
  \item{x}{a vector of values for which a histogram is to be plotted.}
  \item{scale}{the scaling of the vertical axis: \code{"frequency"} (the default),
    \code{"percent"}, or \code{"density"}.}
  \item{\dots}{arguments to be passed to \code{hist}.}
}


}
\value{
  This function returns \code{NULL}, and is called for its side effect ---
  plotting a histogram.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{hist}}}

\examples{
    data(Prestige)
    Hist(Prestige$income, scale="percent")
    }
}
\keyword{hplot}

\eof
\name{Rcmdr.Utilities}
\alias{Rcmdr.Utilities}
\alias{activeDataSet}
\alias{activeModel}
\alias{checkActiveDataSet}
\alias{checkActiveModel}
\alias{checkBoxes}
\alias{checkFactors}
\alias{checkNumeric}
\alias{checkReplace}
\alias{checkTwoLevelFactors}
\alias{checkVariables}
\alias{dialogSuffix}
\alias{doItAndPrint}
\alias{errorCondition}
\alias{getFrame}
\alias{getFrame.listbox}
\alias{getSelection}
\alias{getSelection.listbox}
\alias{groupsBox}
\alias{groupsLabel}
\alias{initializeDialog}
\alias{is.valid.name}
\alias{justDoIt}
\alias{listDataSets}
\alias{listGeneralizedLinearModels}
\alias{listFactors}
\alias{listLinearModels}
\alias{listNumeric}
\alias{listTwoLevelFactors}
\alias{listVariables}
\alias{logger}
\alias{modelFormula}
\alias{OKCancelHelp}
\alias{radioButtons}
\alias{subOKCancelHelp}
\alias{subsetBox}
\alias{variableListBox}

\title{Rcmdr Utility Functions}
\description{
  These functions support writing additions to the Rcmdr package. Additional R code
  can be placed in files with file type \code{.R} in the \code{etc} subdirectory
  of the package. Add menus, submenus, and menu items by editing the file
  \code{Rcmdr-menus.txt} in the same directory.
}

\usage{
activeDataSet(dsname)
activeModel(model)
checkActiveDataSet()
checkActiveModel()
checkBoxes(window=top, frame, boxes, initialValues=NULL, labels)  # macro
checkFactors(n=1)
checkNumeric(n=1)
checkReplace(name, type="Variable")
checkTwoLevelFactors(n=1)
checkVariables(n=1)
dialogSuffix(window=top, onOK=onOK, rows=1, columns=1, focus=top, bindReturn=TRUE, 
    preventGrabFocus=FALSE)  # macro
doItAndPrint(command)
errorCondition(window=top, recall=NULL, message, model=FALSE)  # macro
\method{getFrame}{listbox}(object)
\method{getSelection}{listbox}(object)
groupsBox(recall=NULL, label="Plot by:", initialLabel="Plot by groups",
    plotLinesByGroup=FALSE, positionLegend=FALSE, 
    plotLinesByGroupsText="Plot lines by group")  # macro
groupsLabel(frame=top, groupsBox=groupsBox, columnspan=1)  # macro
justDoIt(command)
initializeDialog(window=top, title="")  # macro
is.valid.name(x)
listDataSets(envir = .GlobalEnv, ...)
listFactors(dataSet=.activeDataSet)
listGeneralizedLinearModels(envir = .GlobalEnv, ...)
listLinearModels(envir = .GlobalEnv, ...)
listNumeric{dataSet=.activeDataSet}
listTwoLevelFactors(dataSet=.activeDataSet)
listVariables(dataSet=.activeDataSet)
logger(command)
modelFormula(frame=top, hasLhs=TRUE)  # macro
OKCancelHelp(window=top, helpSubject=NULL, model=FALSE)  # macro
radioButtons(window=top, name, buttons, values=NULL, initialValue=..values[1], 
    labels, title)  # macro
subOKCancelHelp(window=subdialog, helpSubject=NULL)  # macro
subsetBox(window=top, model=FALSE)  # macro
variableListBox(parentWindow, variableList=.variables, bg="white",
    selectmode="single", export="FALSE", initialSelection=NULL, title)
}

\arguments{
  \item{bg}{background color.}
  \item{bindReturn}{if \code{TRUE}, the \emph{Return} key is bound to the \code{onOK} function in the dialog.}
  \item{boxes}{vector of quoted names for check boxes, used to generate each box and its associated variable.}
  \item{buttons}{vector of quoted names for buttons in a set of related radio buttons.}
  \item{columnspan}{number of dialog-box columns to be spanned by frame.}
  \item{command}{a character string that evaluates to an R command.}
  \item{dataSet, dsname}{the quoted name of a data frame in memory.}
  \item{envir}{the environment to be searched; should generally be left at the default.}
  \item{export}{export selection?}
  \item{focus}{Tk window to get the focus.}
  \item{frame}{frame or quoted name for frame depending upon the function.}
  \item{groupsBox}{listbox object for selecting groups variable.}
  \item{hasLhs}{does the model formula have a left-hand side?}
  \item{helpSubject}{the quoted name of a help subject, to be called as \code{help(helpSubject)}
    when the dialog \emph{Help} button is pressed.}
  \item{initialLabel}{label for groups button before a selection is made.}
  \item{initialSelection}{index of item initially selected, 0-base indexing.}
  \item{initialValue}{for a set of related radio buttons.}
  \item{initialValues}{for a set of related check boxes.}
  \item{label}{label prefix for groups button after a selection is made.}
  \item{labels}{A vector of character strings to label a set of radio buttons or check boxes.}
  \item{message}{error message.}
  \item{model}{the name of a model, as a character string, or \code{TRUE} or \code{FALSE}, depending
    upon the function.}
  \item{name}{quoted name.}
  \item{n}{number of variables to check for.}
  \item{object}{a \code{listbox} object.}
  \item{onOK}{function to execute when the \emph{OK} button is pressed.}
  \item{plotLinesByGroup}{include a check box for plotting lines by group?}
  \item{plotLinesByGroupsText}{the label for the plot-lines-by-group check box.}
  \item{positionLegend}{include a check box for a legend?}
  \item{preventGrabFocus}{prevent the dialog box from grabbing the focus.}
  \item{recall}{function to call after error --- usually the function that initiates the dialog.}
  \item{rows, columns}{numbers of rows and columns of widgets in the dialog box.}
  \item{values}{vector of quoted values associated with radio buttons or check boxes.}
  \item{selectmode}{\code{"single"} or \code{"multiple"}.}
  \item{title}{Window or dialog-box-element title.}
  \item{type}{quoted type of object to check; used to generate check-replace dialog box.}
  \item{variableList}{a vector of variable names.}
  \item{window, parentWindow}{a Tk window.}
  \item{x}{a putative R object name, as a character string.}
  \item{\dots}{Disregard.}
}

\details{

  There are several groups of functions exported by the \code{Rcmdr} package and documented briefly here.
  To see how these functions work, it is simplest to examine the dialog-generating functions in the \code{Rcmdr} package.

  \emph{Executing and logging commands: }
  The functions \code{doItAndPrint}, \code{justDoIt}, and \code{logger} control the 
  execution, logging, and printing of commands generated by menus and dialogs. 
  \code{logger(command)} adds \code{command} to the log/script window and to the output window. 
  \code{justDoIt(command)} causes \code{command}
  to be executed. \code{doItAndPrint(command)} does both of these operations.
  
  \emph{Checking for errors: }
  The function \code{is.valid.name} checks whether a character string specifies a valid name
  for an R object. The functions \code{checkActiveDataSet}, \code{checkActiveModel},
  \code{checkFactors}, \code{checkNumeric}, \code{checkTwoLevelFactors}, and \code{checkVariables}
  check for the existence of objects and bring up an error-information dialog if they are absent
  (or insufficiently numerous, in the case of different kinds of variables). The function 
  \code{checkReplace} opens a dialog to query whether an existing object should be replaced.
  The function \code{errorCondition} reports an error to the user and (optionally) re-starts
  a dialog.
  
  \emph{Information: }
  Several functions return vectors of object names: \code{listDataSets}, \code{listGeneralizedLinearModels}, 
  \code{listFactors}, \code{listLinearModels}, \code{listNumeric}, \code{listTwoLevelFactors}, 
  \code{listVariables}. The functions \code{activeDataSet} and \code{activeModel} respectively report or set the active
  data set and model.
  
  \emph{Building dialog boxes: }
  Several functions simplify the process of constructing Tk dialogs: 
  initializing a dialog box, \code{initializeDialog}, and completing the definition of a dialog box, \code{dialogSuffix};
  a set of check boxes, \code{checkBoxes};
  a set of radio buttons, \code{radioButtons};
  a list box with associated scrollbars and state variable, \code{variableListBox}
  (and the associated functions \code{getFrame} and \code{getSelection});
  a button and subdialog for selecting a "grouping" variable, \code{groupsBox}; 
  displaying the currently defined groups in a dialog, \code{groupsLabel};
  a dialog-box structure for entering a model formula, \code{modelFormula};
  a text box for entering a subsetting expression, \code{subsetBox};
  \emph{OK}, \emph{Cancel}, and \emph{Help} buttons for dialogs, \code{OKCancelHelp}, and subdialogs, \code{subOKCancelHelp}.
  
  Some of these functions, marked \code{# macro} under \emph{Usage}, are "macro-like" in their behaviour, in that they 
  execute in the environment from which they are called. These were defined with an adaptation (used with permission) of
  Thomas Lumley's \code{defmacro} function, described in Lumley (2001).
  
}

\references{
    T. Lumley (2001) Programmer's niche: Macros in R.
    \emph{R News}, \bold{1(3)}, 11--13.
    }

\author{John Fox \email{jfox@mcmaster.ca}}

\keyword{misc}

\eof
\name{RcmdrPager}
\alias{RcmdrPager}

\title{Pager for Text Files}
\description{
  This is a slightly modified version of the tkpager, changed to use the Rcmdr monospaced font
  and a white background.
}
\usage{
RcmdrPager(file, header, title, delete.file)
}

\arguments{
  \item{file}{character vector of file(s) to be displayed.}
  \item{header}{for the beginning of each file.}
  \item{title}{for window}
  \item{delete.file}{delete file(s) on close.}
}

\seealso{\code{\link[tcltk]{tkpager}}}

\keyword{misc}

\eof
\name{Recode}
\alias{Recode}

\title{Rcmdr Recode Dialog}
\description{
  The recode dialog is normally used to recode numeric variables and factors
  into factors, for example by combining values of numeric variables or levels
  of factors. It may also be used to produce new numeric variables. The Rcmdr
  recode dialog is based on the \code{\link[car]{recode}} function in the
  \code{car} package.
}

\details{
The name of the new variable must be
a valid R object name (consisting only of upper and lower-case letters, numerals, and
periods, and not starting with a numeral).

Enter recode directives in the box at the right. Directives are normally entered one per line, 
but may also be separated by semicolons. Each directive is of the form \code{input = output} 
(see the examples below). If an input value satisfies more than one specification, then the 
first (from top to bottom, and left to right) applies. If no specification is satisfied, then 
the input value is carried over to the result. \code{NA} is allowed on input and output. Factor 
levels are enclosed in double-quotes on both input and output.

Several recode specifications are supported: 

\describe{
    \item{a single value}{For example, \code{"missing" = NA}.}
    \item{several values separated by commas}{For example, \code{7,8,9 = "high"}.}
    \item{a range of values indicated by a colon}{For example, \code{7:9 = "high"}. The
        special values \code{low} and \code{high} may appear in a range. For example,
        \code{low:10=1}. Note that these values are unquoted.}
    \item{the special value \code{else}}{everything that does not fit a previous
        specification. For example, \code{else=NA}. Note that \code{else} matches \emph{all}    
        otherwise unspecified values on input, including \code{NA}.}
    }

If all of the output values are numeric, and the "Make new variable a factor" check box is 
unchecked, then a numeric result is returned. 
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[car]{recode}}}

\keyword{manip}

\eof
\name{Scatter3DDialog}
\alias{Scatter3DDialog}
\alias{Scatter3D}
\title{Rcmdr 3D Scatterplot Dialog}

\description{
  This dialog sets up a call to the \code{\link{scatter3d}} function to draw a
  three-dimensional scatterplot.  
}

\details{
The explanatory variables provide the "horizontal" and "out-of-screen" axes of the scatterplot,
the response variable provides the "vertical" axis.

Data points are represented as spheres or points,
depending upon the number of observations. 
  
Several regression surfaces can be
plotted: a linear least-squares surface; a full quadratic least-squares surface
with squared and cross-product terms; a "smooth" regression surface --- either a
smoothing spline, if no degrees of freedom are specified (in which case the
\code{\link[mgcv]{gam}} function selects the df by generalized cross validation),
or a fixed-df regression spline; an additive-regression surface (also fit by \code{gam}),
with either smoothing spline or regression spline components (again selected according
to the specification of degrees of freedom). If only one surface is fit, then residuals are
plotted as red (negative) and green (positive) lines from the surface to the points.

You can specify a factor defining groups by pressing the \emph{Plot by groups} button. A
separate surface or set of surfaces is plotted for each level of the groups factor. These
surfaces can be constrained to be parallel.
  
The completed plot can be manipulated with the mouse: Click, hold, drag the left mouse button to rotate
the display; click, hold, and drag the right button to zoom in and out.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link{scatter3d}}, \code{\link[rgl]{rgl.open}}, \code{\link[mgcv]{gam}}}

\keyword{hplot}

\eof
\name{aboutRcmdr}
\alias{aboutRcmdr}

\title{About the Rcmdr Package}
\description{
  Rcdmr Version 0.9-11
}

\author{John Fox \email{jfox@mcmaster.ca}}

\keyword{misc}

\eof
\name{bin.var}
\alias{bin.var}

\title{Bin a Numeric Varisible}

\description{
  Create a factor dissecting the range of a numeric variable into
  bins of equal width, (roughly) equal frequency, or at "natural"
  cut points. The \code{\link[base]{cut}} function is used to create the factor.
}

\usage{
bin.var(x, bins = 4, method = c("intervals", "proportions", "natural"), labels = FALSE)
}

\arguments{
  \item{x}{numeric variable to be binned.}
  \item{bins}{number of bins.}
  \item{method}{one of \code{"intervals"} for equal-width bins;
    \code{"proportions"} for equal-count bins;
    \code{"natural"} for cut points between bins to be determined
    by a k-means clustering.}
  \item{labels}{if \code{FALSE}, numeric labels will be used for the factor levels;
    if \code{NULL}, the cut points are used to define labels; otherwise a character
    vector of level names.}
}

\value{
  A factor.
}

\author{Dan Putler, slightly modified by John Fox \email{jfox@mcmaster.ca}
    with the original author's permission.}

\seealso{\code{\link[base]{cut}}, \code{\link[stats]{kmeans}}.}

\examples{
summary(bin.var(rnorm(100), method="prop", labels=letters[1:4]))
}
  
\keyword{manip}

\eof
\name{colPercents}
\alias{colPercents}
\alias{rowPercents}

\title{Row and Column Percentage Tables}
\description{
  Percentage a matrix or higher-dimensional array of frequency counts by
  rows or columns.
}
\usage{
colPercents(tab, digits=2)
rowPercents(tab, digits=2)
}

\arguments{
  \item{tab}{a matrix or higher-dimensional array of frequency counts.}\
  \item{digits}{number of places to the right of the decimal place for percentages.}
}

}
\value{
  Returns an array of the same size and shape as \code{tab} percentaged by
  rows or columns, plus rows or columns of totals and counts.
}

\author{John Fox \email{jfox@mcmaster.ca}}


\keyword{misc}


\eof
\name{generalizedLinearModel}
\alias{generalizedLinearModel}

\title{Rcmdr Generalized Linear Model Dialog}
\description{
  This dialog is used to specify a generalized linear model to be fit by the 
  \code{\link[base]{glm}} function.
}

\details{
Enter a name for the generalized linear model to be fit if you want to retain more than one model. 
The model 
name must be a valid R object name (consisting only of upper and lower-case letters, numerals, and
periods, and not starting with a numeral).

The left model-formula box specifies the response variable to be used in the model; it
may be a variable name or an expression evaluating to the response variable, such as
\code{working == "Fulltime"}.

The right model-formula box specifies the right-hand (i.e., predictor) side of the model.
See \code{\link[base]{glm}} for details.

You can type directly in the model formula boxes. Alternatively, double-clicking the left mouse
button on a variable in the variable-list transfers it to the left-hand side of the model (if
it is empty) or to the right-hand side. 
Factors are indicated in the variable list; all other variables are numeric.
You can also enter operators and parentheses using the buttons
above the formula.

Double-click the left mouse button to select a family in the "Family" box and the corresponding
permissible link functions appear in the "Link function" box to the right. Initially, the
canonical link for the family is selected. See \code{\link[base]{family}} for details.

Specifying a subset expression allows you to fit the model to a subset of observations
in the active data set. For example, assuming that \code{gender} is a variable in the
active data set, entering \code{gender == "Male"} would restrict the model to males.

If the active model is a generalized linear model, and the active data set has not changed, 
then the initial values of the left-hand-side,
right-hand-side, family, link, and subset fields are retained from the active model.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{glm}}, \code{\link[base]{family}}, \code{\link[base]{Comparison}}}

\keyword{models}

\eof
\name{linearModel}
\alias{linearModel}

\title{Rcmdr Linear Model Dialog}
\description{
  This dialog is used to specify a linear model to be fit by the \code{\link[base]{lm}} function.
}

\details{
Enter a name for the linear model to be fit if you want to retain more than one model. The model 
name must be a valid R object name (consisting only of upper and lower-case letters, numerals, and
periods, and not starting with a numeral).

The variable-list box is there only to remind you of the names of variables in the active data set.
Factors are indicated in the variable list; all other variables are numeric.

The left model-formula box specifies the response variable to be used in the model; it
may be a variable name or an expression evaluating to the response variable, such as
\code{log(income)}.

The right model-formula box specifies the right-hand (i.e., predictor) side of the model.
See \code{\link[base]{lm}} for details.

You can type directly in the model formula boxes. Alternatively, double-clicking the left mouse
button on a variable in the variable-list transfers it to the left-hand side of the model (if
it is empty) or to the right-hand side. You can also enter operators and parentheses using the buttons
above the formula.

Specifying a subset expression allows you to fit the model to a subset of observations
in the active data set. For example, assuming that \code{gender} is a variable in the
active data set, entering \code{gender == "Male"} would restrict the model to males.

If the active model is a linear model and the active data set has not changed, 
then the initial values of the left-hand-side,
right-hand-side, and subset fields are retained from the previous model.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{lm}}, \code{\link[base]{Comparison}}}

\keyword{models}

\eof
\name{partial.cor}
\alias{partial.cor}

\title{Partial Correlations}
\description{
  Computes a matrix of partial correlations between each pair of variables
  controlling for the others.
}
\usage{
partial.cor(X, ...)
}

\arguments{
  \item{X}{data matrix.}
  \item{\dots}{arguments to be passed to \code{cor}.}
}

}
\value{
    Returns a matrix of partial correlations.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{cor}}}

\examples{
    data(DavisThin)
    partial.cor(DavisThin)
}
\keyword{misc}

\eof
\name{plotMeans}
\alias{plotMeans}
\title{Plot Means for One or Two-Way Layout}

\description{
Plots cell means for a numeric variable in each category of a factor or in each
combination of categories of two factors, optionally along with error bars based
on cell standard errors or standard deviations.
}

\usage{
plotMeans(response, factor1, factor2, error.bars = c("se", "sd", "conf.int", "none"), level=0.95,
    xlab = deparse(substitute(factor1)), ylab = paste("mean of", deparse(substitute(response))), 
    legend.lab = deparse(substitute(factor2)), main = "Plot of Means", 
    pch = 1:n.levs.2, lty = 1:n.levs.2, col = palette())
}

\arguments{
  \item{response}{Numeric variable for which means are to be computed.}
  \item{factor1}{Factor defining horizontal axis of the plot.}
  \item{factor2}{If present, factor defining profiles of means}
  \item{error.bars}{If \code{"se"}, the default, error bars around means
    give plus or minus one standard error of the mean; if \code{"sd"}, error
    bars give plus or minus one standard deviation; if \code{"conf.int"}, error
    bars give a confidence interval around each mean; if \code{"none"}, error
    bars are suppressed.}
  \item{level}{level of confidence for confidence intervals; default is .95}
  \item{xlab}{Label for horizontal axis.}
  \item{ylab}{Label for vertical axis.}
  \item{legend.lab}{Label for legend.}
  \item{main}{Label for the graph.}
  \item{pch}{Plotting characters for profiles of means.}
  \item{lty}{Line types for profiles of means.}
  \item{col}{Colours for profiles of means}
}

\value{
  The function invisibly returns \code{NULL}.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{interaction.plot}}}

\keyword{hplot}

\eof
\name{reliability}
\alias{reliability}
\alias{print.reliability}

\title{Reliability of a Composite Scale}
\description{
  Calculates Cronbach's alpha and standardized alpha (lower bounds on reliability)
  for a composite (summated-rating) scale. Standardized alpha is for the sum of the
  standardized items. In addition, the function calculates alpha and standardized
  alpha for the scale with each item deleted in turn, and computes the correlation
  between each item and the sum of the other items.
}

\usage{
reliability(S)

\method{print}{reliability}(x, digits=4, ...)
}

\arguments{
  \item{S}{the covariance matrix of the items; normally, there should be at least 3 items
  and certainly no fewer than 2.}
  \item{x}{reliability object to be printed.}
  \item{digits}{number of decimal places.}
  \item{...}{not used: for compatibility with the print generic."}
}

}
\value{
    an object of class reliability, which normally would be printed.
}

\references{
    N. Cliff (1986) Psychological testing theory. Pp. 343--349 in
    S. Kotz and N. Johnson, eds., \emph{Encyclopedia of Statistical Sciences, Vol. 7}.
    Wiley.}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{cov}}}

\examples{
data(DavisThin)
reliability(cov(DavisThin))
}
\keyword{misc}

\eof
\name{scatter3d}
\alias{scatter3d}
\title{Three-Dimensional Scatterplots}

\description{
  This function uses the \code{rgl} package to draw 3D scatterplots
  with various regression surfaces.
}

\usage{
scatter3d(x, y, z, xlab=deparse(substitute(x)), ylab=deparse(substitute(y)),
    zlab=deparse(substitute(z)), revolutions=0, bg.col=c("black", "white"), axis.col=NULL,
    surface.col=c("blue", "green", "orange", "magenta", "cyan", "red", "yellow", "gray"), 
    neg.res.col="red", pos.res.col="green", point.col="yellow",
    text.col=axis.col, grid.col=if (bg.col == "white") "black" else "gray", 
    fogtype=c("exp2", "linear", "exp", "none"), 
    residuals=(length(fit) == 1), surface=TRUE, grid=TRUE, df.smooth=NULL, df.additive=NULL,
    sphere.size=1, threshold=0.01, speed=1, fov=60, 
    fit="linear", groups=NULL, parallel=TRUE, model.summary=FALSE)
}

\note{
You have to install the \code{rgl} and \code{mgcv} packages to produce 3D plots. 
}

\arguments{
  \item{x}{variable for horizontal axis.}
  \item{y}{variable for vertical axis (response).}
  \item{z}{variable for out-of-screen axis.}
  \item{xlab, ylab, zlab}{axis labels.}
  \item{revolutions}{number of full revolutions of the display.}
  \item{bg.col}{background colour; one of \code{"white"}, \code{"black"}.}
  \item{axis.col}{colour for axes; default is \code{"white"} for black background, 
    \code{"black"} for white background.}
  \item{surface.col}{vector of colours for regression planes, 
    used in the order specified by \code{fit}.}
  \item{neg.res.col, pos.res.col}{colours for lines representing negative 
    and positive residuals.}
  \item{point.col}{colour of points.}
  \item{text.col}{colour of axis labels.}
  \item{grid.col}{colour of grid lines on the regression surface(s).}
  \item{fogtype}{type of fog effect; one of \code{"exp2"}, \code{"linear"}, 
    \code{"exp"}, \code{"none".}}
  \item{residuals}{plot residuals (\code{TRUE} or \code{FALSE}); available only 
    when there is one surface plotted.}
  \item{surface}{plot surface(s) (\code{TRUE} or \code{FALSE}).}
  \item{grid}{plot grid lines on the regression surface(s) (\code{TRUE} or \code{FALSE}).}
  \item{df.smooth}{degrees of freedom for the two-dimensional smooth regression surface;
    if \code{NULL} (the default), the \code{\link[mgcv]{gam}} function will select the degrees of freedom
    for a smoothing spline by generalized cross-validation; if a positive number, a fixed
    regression spline will be fit with the specified degrees of freedom.}
  \item{df.additive}{degrees of freedom for each explanatory variable in an additive regression;
    if \code{NULL} (the default), the \code{gam} function will select degrees of freedom 
    for the smoothing splines by generalized cross-validation; if a positive number
    or a vector of two positive numbers, fixed
    regression splines will be fit with the specified degrees of freedom for each term.}
  \item{sphere.size}{relative sizes of spheres representing points; 
    the actual size is dependent on the number of observations.}
  \item{threshold}{if the actual size of the spheres is less than the threshold, 
    points are plotted instead.}
  \item{speed}{relative speed of revolution of the plot.}
  \item{fov}{field of view (in degrees); controls degree of perspective.}
  \item{fit}{one or more of \code{"linear"}, \code{"quadratic"}, \code{"smooth"}, 
    \code{"additive"}; to display fitted surface(s); partial matching is supported -- 
    e.g., \code{c("lin", "quad")}.}
  \item{groups}{if \code{NULL} (the default), no groups are defined; if a factor, a different surface
    or set of surfaces is plotted for each level of the factor; in this event, the colours in 
    \code{plane.col} are used successively for the points, surfaces, and residuals corresponding to
    each level of the factor.}
  \item{parallel}{when plotting surfaces by \code{groups}, should the surfaces be constrained to be
    parallel? A logical value, with default \code{TRUE}.}
  \item{model.summary}{print summary or summaries of the model(s) fit 
    (\code{TRUE} or \code{FALSE}).}
}

\value{
  Does not return a useful value; used for its side-effect of
  creating a 3D scatterplot.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[rgl]{rgl.open}}, \code{\link[mgcv]{gam}}}

\examples{
    \dontrun{
data(state)
State.x77 <- as.data.frame(state.x77)
with(State.x77, scatter3d(Income, Murder, Illiteracy))
with(State.x77,  scatter3d(Income, Murder, Illiteracy, fit=c("linear", "quadratic")))
    }
}

\keyword{hplot}

\eof
\name{stem.leaf}
\alias{stem.leaf}
\alias{print.stem.leaf}

\title{Stem-and-Leaf Display}
\description{
  Creates a classical ("Tukey-style") stem-and-leaf display.
}

\usage{
stem.leaf(data, unit, m, Min, Max, rule.line = c("Dixon", "Velleman", "Sturges"), 
    style = c("Tukey", "bare"), trim.outliers = TRUE, depths = TRUE,
    reverse.negative.leaves = TRUE)

\method{print}{stem.leaf}(x, ...)
}

\arguments{
  \item{data}{a numeric vector.}
  \item{unit}{leaf unit, as a power of 10 (e.g., \code{100}, \code{.01});
    omit to let the function choose the unit.}
  \item{m}{number of parts (1, 2, or 5) into which each stem should be
    divided; omit to let the function choose the number of parts/stem.}
  \item{Min}{smallest non-outlying value; omit for automatic choice.}
  \item{Max}{largest non-outlying value; omit for automatic choice.}
  \item{rule.line}{the rule to use for choosing the desired number of lines
    in the display; \code{"Dixon"} = 10*log10(n); \code{"Velleman"} = 2*sqrt(n);
    \code{"Sturges"} = 1 + log2(n); the default is \code{"Dixon"}.}
  \item{style}{\code{"Tukey"} (the default) for "Tukey-style" divided stems;
    \code{"bare"} for divided stems that simply repeat the stem digits.}
  \item{trim.outliers}{if \code{TRUE} (the default), outliers are placed on \code{LO} and
    \code{HI} stems.}
  \item{depths}{if \code{TRUE} (the default), print a column of "depths" to the left of the
    stems; the depth of the stem containing the median is the stem-count enclosed in
    parentheses.}
  \item{reverse.negative.leaves}{if \code{TRUE} (the default), reverse the leaves on negative
    stems (so, e.g., the leaf 9 comes before the leaf 8, etc.).}
  \item{x}{an object of class stem.leaf to be printed.}
  \item{...}{not used: for compatibility with the generic print function.}
}

\details{
  Unlike the \code{stem} function in the \code{base} package, this function produces
  classic stem-and-leaf displays, as described in Tukey's \emph{Exploratory Data Analysis}.
  Outliers are determined using the rule for boxplots (see \code{\link[base]{boxplot.stats}}).
}

\value{
  Returns on object of class stem.leaf, which normally would be printed.
}

\references{
    Tukey, J. 
    \emph{Exploratory Data Analysis.}
    Addison-Wesley, 1977.
    }

\author{Peter Wolf, slightly modified by John Fox \email{jfox@mcmaster.ca}
    with the original author's permission.}

\seealso{\code{\link[base]{stem}}}

\examples{
data(Prestige)
stem.leaf(Prestige$income)
}

\keyword{misc} 

\eof
